APP_NAME = "AlectioCLI"
SSO_URL = "http://alectio.localhost.com:4200/SSO/login/"
BACKEND_URL = "https://devbackend.alectio.com"
URL_CREATE_PROJECT = f"{BACKEND_URL}/projects/create"
URL_CREATE_EXPERIMENT = f"{BACKEND_URL}/projects/addExperimentsInfo"
URL_TOKEN_VALIDATE = f"{BACKEND_URL}/users/projects"
URL_GET_EXP_TOKEN = f"{BACKEND_URL}/experiments/get_token"
INSTRUCTION_UPLOAD_URL = f"{BACKEND_URL}/instructions/upload"
CLASSES_URL = f"{BACKEND_URL}/project/classes"
MARKETPLACE_RECOMMENDATION_URL = f"{BACKEND_URL}/partners/recommended"
AUTOLABEL_CLASS = f"{BACKEND_URL}/autoLabel/models/type"
INSTRUCTION_UPLOAD_URL = f"{BACKEND_URL}/instructions/upload"
PROJECT_LIST_URL = f"{BACKEND_URL}/users/projects"
DELETE_PROJECT_URL = f"{BACKEND_URL}/projects/delete"
